================================
Creating a distributable package
================================

This tutorial will guide you through all the steps of creating a package from
scratch all the way to uploading it on PyPi_.

Setting up your development environment
=======================================

I will assume you already have a development environment running with
pkglts installed. If not check :doc:`dvlpt_env`.

In the following, I will assume you have created a 'dvlpt' virtual environment
and that you activated it. Just forget about it if you are not using virtual
environments.

Create a new basic package
==========================

Create package

add options base, test, doc, version, license

Make a distribution of your package
===================================

Use of pyproject option

Check your code thoroughly
==========================

add options coverage, flake8, tox

Make your package available to the community
============================================

add pypi option

To go further
=============

See :doc:`web_tools`.

.. _PyPi: https://pypi.python.org/pypi
